@@ -21,6 +21,7 @@ import (
 	"github.com/abiosoft/colima/environment/vm/lima"
 	"github.com/abiosoft/colima/environment/vm/lima/limautil"
 	"github.com/abiosoft/colima/util"
+	"github.com/docker/go-units"
 	log "github.com/sirupsen/logrus"
 )
 
@@ -30,7 +31,7 @@ type App interface {
 	Stop(force bool) error
 	Delete() error
 	SSH(layer bool, args ...string) error
-	Status() error
+	Status(extended bool) error
 	Version() error
 	Runtime() (string, error)
 	Kubernetes() (environment.Container, error)
@@ -294,14 +295,14 @@ func (c colimaApp) SSH(layer bool, args ...string) error {
 	if len(args) > 0 {
 		args = append([]string{"-q", "-t", resp.IPAddress, "--"}, args...)
 	} else if workDir != "" {
-		args = []string{"-q", "-t", resp.IPAddress, "--", "cd " + workDir + " 2> /dev/null; bash --login"}
+		args = []string{"-q", "-t", resp.IPAddress, "--", "cd " + workDir + " 2> /dev/null; \"$SHELL\" --login"}
 	}
 
 	args = append(util.ShellSplit(cmdArgs), args...)
 	return cli.CommandInteractive("ssh", args...).Run()
 }
 
-func (c colimaApp) Status() error {
+func (c colimaApp) Status(extended bool) error {
 	ctx := context.Background()
 	if !c.guest.Running(ctx) {
 		return fmt.Errorf("%s is not running", config.CurrentProfile().DisplayName)
@@ -340,6 +341,17 @@ func (c colimaApp) Status() error {
 		log.Println("kubernetes: enabled")
 	}
 
+	// additional details
+	if extended {
+		log.Println("networkDriver:", conf.Network.Driver)
+
+		if inst, err := limautil.Instance(); err == nil {
+			log.Println("cpu:", inst.CPU)
+			log.Println("mem:", units.BytesSize(float64(inst.Memory)))
+			log.Println("disk:", units.BytesSize(float64(inst.Disk)))
+		}
+	}
+
 	return nil
 }
 
